Stan Math Library: stan::error_index Struct Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- Class List
- Class Index
- Class Hierarchy
- Class Members

Public Types | List of all members
stan::error_index Struct Reference

`#include <error_index.hpp>`

## Public Types
enum | { value }

## Detailed Description

Definition at line 6 of file error_index.hpp.

## Member Enumeration Documentation

anonymous enum

Enumerator
value |

Definition at line 7 of file error_index.hpp.

The documentation for this struct was generated from the following file:

- stan/math/prim/scal/meta/error_index.hpp

[ Stan Home Page ] © 2011–2016, Stan Development Team.